#ifndef __dlgutilsh__
#define __dlgutilsh__

//**************************************************************************************
//
//	File:			dlgutils.h
//					Copyright 1989-92 Capilano Computing Systems Ltd.
//					All Rights Reserved.
//
//
//	Written by:		Addam Smith
//	Created:		1.1.91, from DevEditUtils.DEF (p2c)
//
//	Modify History:	5.14.91 Addam Smith
//					ADDED: Prototypes for routines imported from "utilities.c" in
//						MacABEL.
//
//					5.29.92, Addam Smith
//					ADDED: Prototypes for routines imported from "utils.c" in
//						FromABEL, "KeyPressed()".
//
//					10.1.92, Addam Smith
//					ADDED: "titleItem" field to tPopUpItem to handle inverting
//						the static text item beside the menu.  A value 0 or less
//						implies it isn't present.  Also needed parameter for the
//						NewPopUpItem().
//
//	Compiler:		MPW-C 3.3
//
//	Description:	This file is header for dialog utility routines and structures.
//
//**************************************************************************************



//*************************** INCLUDES *********************************

/***************** ToolBox Imports *************************/
 
#include <Carbon/Carbon.h>


//********************** CONSTANTS/TYPES/GLOBALS ***********************

	// General AS Dialog Constants
	
#define	cOKItem			1
#define cCancelItem		2

	// Constant DlgItem Types
	
#define cListType		1
#define cPopUpType		2
#define cTextType		3


	// Special Dialog Item structures
	
typedef struct tListItem *pTListItem;
typedef struct tListItem
{
	ListHandle hList;		// List mgr data handle 
	long listTime;			// Last event time for special updates 
	short doubleClickItem;	// Cell double click equivalent item no. 
	short numRows;			// Number of row cells 
	short numColumns;		// Number of column cells 
}
tListItem;


typedef struct tPopUpItem *pTPopUpItem;
typedef struct tPopUpItem
{
	MenuHandle hMenu;		// Pop-Up menu handle 
	short activeItem;		// Current popup item selected 
	Str255 activeName;		// Menu item name showing 
	short titleItem;		// Pop-Up static text title item number to invert 
	Rect maxRect;			// Max. pop-up rect size, also gives center pt. 
	Point penPt;			// Point to moveto before drawing active name text 
}
tPopUpItem;


typedef struct tTextItem *pTTextItem;
typedef struct tTextItem
{
	Ptr pText;				// Pointer to text block to display 
	long textLength;		// Number of chars in hText handle 
	short textFont;			// Font type to use 
	Style textStyle;		// Style  "   "  "  
	short textSize;			// Size   "   "  "  
	short textMode;			// Mode   "   "  "  
	short textJust;			// Justification for TextBox call 
}
tTextItem;

typedef struct tDlgItem *pTDlgItem;
typedef struct tDlgItem
{
	short itemType;			// Integer for dlog item type within union 
	short itemNum;			// Integer for dlog item number in DITL 
	Rect itemRect;			// Local rectangle of item in dialog 
	void *pItemRec;			// Ptr to structure of "itemType" 
	pTDlgItem pNext;		// Next special item in our dialog list 
}
tDlgItem;



//************************* PROTOTYPES *********************************

#ifdef __cplusplus
extern "C" {
#endif

	// tDlgItem Routines
	
pTDlgItem NewDlgItem(DialogPtr diaPtr,short itemType,short itemNum,void *pItemRec );

void AddDlgItem( pTDlgItem *ppDlgHead,pTDlgItem pAddDlgItem );

void DisposeDlgItem( pTDlgItem *pDisposeDlgItem );


	// tListItem Routines
	
pTListItem NewListItem( ListHandle hList,short doubleClickItem,
						short numRows, short numColumns );
					
void DisposeListItem( pTListItem *pDisposeListItem );

ListHandle CreateNewList(	DialogPtr diaPtr,short listItem,
							Point cellSize,short numRows,short numColumns,
							Boolean scrollHoriz,Boolean scrollVert );
					
void SetDrawListItemProc(DialogPtr diaPtr,short listUserItem );


	// tPopUpItem Routines
	
pTPopUpItem NewPopUpItem(	MenuHandle hMenu,
							short activeItem,char *pActiveName,short titleItem,
							Rect *maxRect,Point *penPt );
					
void DisposePopUpItem( pTPopUpItem *pDisposePopUpItem );

void CalcPopUpRect( Rect *maxPopUpRect,Rect *popUpRect,
					Point *popUpPenPt,char *popUpStr );
					
void CalcPopUpRect2(	Rect *maxPopUpRect,Rect *popUpRect,
						Point *popUpPenPt,char *popUpStr );
					
Boolean SetupPopUpItem(		DialogPtr diaPtr, short popUpUserItem,
							MenuHandle hPopUpMenu, short startMenuItem,
							pTDlgItem *ppDlgHead );
							
short PopUpItemHit( DialogPtr diaPtr, pTDlgItem pDlgHead, short itemHit );

void SetDrawPopUpItemProc(DialogPtr diaPtr,short popUpUserItem );


	// tTextItem Routines
	
pTTextItem NewTextItem( Ptr pText,long textLength,short textFont,
					Style textStyle,short textSize,short textMode,short textJust );
void DisposeTextItem( pTTextItem *pDisposeTextItem );
void SetDrawTextItemProc(DialogPtr diaPtr,short textUserItem );


	// tDefaultItem Routines 
	
void SetDrawDefaultItemProc(DialogPtr diaPtr,short defaultUserItem );


	// Advanced Dialog Routines
	
void DlgTEScrapStart( void );
void DlgTEScrapEnd( void );
pascal Boolean DlgListFilter(DialogPtr diaPtr,EventRecord *theEvent,short *itemHit );


	// Dialog Setting Routines
	
Boolean GoodNum( register StringPtr numStr );
void SetEText( DialogPtr dPtr,short patItem,StringPtr patStr );
void GetEText( DialogPtr dPtr,short patItem,StringPtr patStr );
void SetCheck( DialogPtr dPtr,short ChkItem,short Value );
void GetCheck( DialogPtr dPtr,short ChkItem,Boolean *Value );
void SetButton( DialogPtr diaPtr,short button,short firstButton,short lastButton );
Handle GetButton( DialogPtr dPtr,short btnItem );
void CenterDLOG( DialogPtr diaPtr );
void GetDlogOrigin( short dlogID, register Point *where );


	// Misc.
	
// Boolean KeyPressed( short keyNum );


#ifdef __cplusplus
}
#endif


#endif	// __dlgutilsh__
